# Zyx

`zyx` is a framework for building LLM applications. It is designed to be a simple and flexible toolkit for building LLM applications. It is built on top of `litellm` and `chromadb` and is designed to be a simple and flexible toolkit for building LLM applications.

## Installation

```bash
pip install zyx
```

## Documentation

Head to [Zyx Documentation](https://zyx.hammad.fun) to learn more.